
// MuseScore plugin for displaying scores in shakuhachi notation
// by using the ShakuViewer software by Razvan Beuran:
//    http://sites.google.com/site/razvanswebsite/shakuhachi/software

//-------------------------------------------------------------------
// init: Called on MuseScore startup
//-------------------------------------------------------------------
function init()
{
}

//-------------------------------------------------------------------
// run: Called when activating the plugin menu entry
// ------------------------------------------------------------------
function run()
{

    //////////////////////////////////////////////////////////
    // IMPORTANT
    // Change the variable SV_PATH below to indicate the location where 
    // the ShakuViewer software is installed on your computer
    // * Example for Windows (use '\\' or '/' for each slash character)
    // var SV_PATH = "C:\\Users\\XYZ\\ShakuViewer-0.3";
    // * Example for Mac OS and Unix
    // var SV_PATH = "/Users/XYZ/ShakuViewer-0.3";
    var SV_PATH = "/PATH/TO/ShakuViewer";
    //////////////////////////////////////////////////////////


    // Check whether the current score is undefined or null
    if (typeof curScore === 'undefined' || curScore == null)
        return;
    
    // Create the path and names for the generated files, which will be placed
    // in the directory where ShakuViewer is installed
    var fileBase = SV_PATH + "/plugin";
    var scoreName = fileBase + "_score.xml";
    var stderrName = fileBase + "_stderr.txt";
    var stdoutName = fileBase + "_stdout.txt";

    // Save the current score temporarily in MusicXML format
    curScore.save(scoreName, "xml");

    // Create the java process to be executed
    // NOTE: see http://doc.qt.nokia.com/latest/qprocess.html
    var process = new QProcess();
    var args = new Array();
    args[0] = "-jar";                       // option for running the JAR file
    args[1] = SV_PATH + "/ShakuViewer.jar"; // the actual JAR file
    args[2] = scoreName;                    // the temporary score name

    // Log the process output for debugging purposes
    process.setStandardErrorFile(stderrName);
    process.setStandardOutputFile(stdoutName);

    // Start the java process
    process.start("java", args);
}

//-------------------------------------------------------------------
// close: Called when unloading the plugin (optional)
//-------------------------------------------------------------------
function close()
{
}

//-------------------------------------------------------------------
// Plugin properties array
// -------------------------------------------------------------------
var museScorePlugin = {
    majorversion: 0,
    minorversion: 2,
    menu:         'Plugins.Open in ShakuViewer',
    init:         init,
    run:          run,
    onClose:      close
};

// Run the plugin
museScorePlugin;
